@@ -2,20 +2,20 @@
 Scrapy - a screen scraping framework written in Python
 """
 
-version_info = (0, 14, 3)
-__version__ = "0.14.3"
+version_info = (0, 16, 0)
+__version__ = "0.16.0"
 
 import sys, os, warnings
 
-if sys.version_info < (2,5):
-    print "Scrapy %s requires Python 2.5 or above" % __version__
+if sys.version_info < (2,6):
+    print "Scrapy %s requires Python 2.6 or above" % __version__
     sys.exit(1)
 
 # ignore noisy twisted deprecation warnings
 warnings.filterwarnings('ignore', category=DeprecationWarning, module='twisted')
 
 # monkey patches to fix external library issues
-from scrapy.xlib import twisted_250_monkeypatches, urlparse_monkeypatches
+from scrapy.xlib import urlparse_monkeypatches
 
 # optional_features is a set containing Scrapy optional features
 optional_features = set()
@@ -33,3 +33,10 @@ except ImportError:
     pass
 else:
     optional_features.add('boto')
+
+try:
+    import libxml2
+except ImportError:
+    pass
+else:
+    optional_features.add('libxml2')
