@@ -1,7 +1,4 @@
-from __future__ import with_statement
-
 import sys
-import os
 import optparse
 import cProfile
 import inspect
@@ -9,10 +6,11 @@ import inspect
 import scrapy
 from scrapy.crawler import CrawlerProcess
 from scrapy.xlib import lsprofcalltree
-from scrapy.conf import settings
 from scrapy.command import ScrapyCommand
 from scrapy.exceptions import UsageError
 from scrapy.utils.misc import walk_modules
+from scrapy.utils.project import inside_project, get_project_settings
+from scrapy.settings.deprecated import check_deprecated_settings
 
 def _iter_command_classes(module_name):
     # TODO: add `name` attribute to commands and and merge this function with
@@ -32,7 +30,7 @@ def _get_commands_from_module(module, inproject):
             d[cmdname] = cmd()
     return d
 
-def _get_commands_dict(inproject):
+def _get_commands_dict(settings, inproject):
     cmds = _get_commands_from_module('scrapy.commands', inproject)
     cmds_module = settings['COMMANDS_MODULE']
     if cmds_module:
@@ -47,49 +45,31 @@ def _pop_command_name(argv):
             return arg
         i += 1
 
-def _print_header(inproject):
+def _print_header(settings, inproject):
     if inproject:
         print "Scrapy %s - project: %s\n" % (scrapy.__version__, \
             settings['BOT_NAME'])
     else:
         print "Scrapy %s - no active project\n" % scrapy.__version__
 
-def _print_commands(inproject):
-    _print_header(inproject)
+def _print_commands(settings, inproject):
+    _print_header(settings, inproject)
     print "Usage:"
     print "  scrapy <command> [options] [args]\n"
     print "Available commands:"
-    cmds = _get_commands_dict(inproject)
+    cmds = _get_commands_dict(settings, inproject)
     for cmdname, cmdclass in sorted(cmds.iteritems()):
         print "  %-13s %s" % (cmdname, cmdclass.short_desc())
+    if not inproject:
+        print
+        print "  [ more ]      More commands available when run from project directory"
     print
     print 'Use "scrapy <command> -h" to see more info about a command'
 
-def _print_unknown_command(cmdname, inproject):
-    _print_header(inproject)
+def _print_unknown_command(settings, cmdname, inproject):
+    _print_header(settings, inproject)
     print "Unknown command: %s\n" % cmdname
     print 'Use "scrapy" to see available commands' 
-    if not inproject:
-        print
-        print "More commands are available in project mode"
-
-def _check_deprecated_scrapy_ctl(argv, inproject):
-    """Check if Scrapy was called using the deprecated scrapy-ctl command and
-    warn in that case, also creating a scrapy.cfg if it doesn't exist.
-    """
-    if not any('scrapy-ctl' in x for x in argv):
-        return
-    import warnings
-    warnings.warn("`scrapy-ctl.py` command-line tool is deprecated and will be removed in Scrapy 0.11, use `scrapy` instead",
-        DeprecationWarning, stacklevel=3)
-    if inproject:
-        projpath = os.path.abspath(os.path.dirname(os.path.dirname(settings.settings_module.__file__)))
-        cfg_path = os.path.join(projpath, 'scrapy.cfg')
-        if not os.path.exists(cfg_path):
-            with open(cfg_path, 'w') as f:
-                f.write("# generated automatically - feel free to edit" + os.linesep)
-                f.write("[settings]" + os.linesep)
-                f.write("default = %s" % settings.settings_module_path + os.linesep)
 
 def _run_print_help(parser, func, *a, **kw):
     try:
@@ -101,33 +81,46 @@ def _run_print_help(parser, func, *a, **kw):
             parser.print_help()
         sys.exit(2)
 
-def execute(argv=None):
+def execute(argv=None, settings=None):
     if argv is None:
         argv = sys.argv
+
+    # --- backwards compatibility for scrapy.conf.settings singleton ---
+    if settings is None and 'scrapy.conf' in sys.modules:
+        from scrapy import conf
+        if hasattr(conf, 'settings'):
+            settings = conf.settings
+    # ------------------------------------------------------------------
+
+    if settings is None:
+        settings = get_project_settings()
+    check_deprecated_settings(settings)
+
     crawler = CrawlerProcess(settings)
     crawler.install()
-    inproject = bool(settings.settings_module)
-    _check_deprecated_scrapy_ctl(argv, inproject) # TODO: remove for Scrapy 0.11
-    cmds = _get_commands_dict(inproject)
+    inproject = inside_project()
+    cmds = _get_commands_dict(settings, inproject)
     cmdname = _pop_command_name(argv)
     parser = optparse.OptionParser(formatter=optparse.TitledHelpFormatter(), \
         conflict_handler='resolve')
     if not cmdname:
-        _print_commands(inproject)
+        _print_commands(settings, inproject)
         sys.exit(0)
     elif cmdname not in cmds:
-        _print_unknown_command(cmdname, inproject)
+        _print_unknown_command(settings, cmdname, inproject)
         sys.exit(2)
 
     cmd = cmds[cmdname]
     parser.usage = "scrapy %s %s" % (cmdname, cmd.syntax())
     parser.description = cmd.long_desc()
     settings.defaults.update(cmd.default_settings)
-    cmd.set_crawler(crawler)
+    cmd.settings = settings
     cmd.add_options(parser)
     opts, args = parser.parse_args(args=argv[1:])
     _run_print_help(parser, cmd.process_options, args, opts)
+    cmd.set_crawler(crawler)
     _run_print_help(parser, _run_command, cmd, args, opts)
+    sys.exit(cmd.exitcode)
 
 def _run_command(cmd, args, opts):
     if opts.profile or opts.lsprof:
