@@ -7,56 +7,68 @@ See documentation in docs/topics/shell.rst
 import signal
 
 from twisted.internet import reactor, threads
-from twisted.python.failure import Failure
+from twisted.python import threadable
+from w3lib.url import any_to_uri
 
-from scrapy import log
 from scrapy.item import BaseItem
 from scrapy.spider import BaseSpider
 from scrapy.selector import XPathSelector, XmlXPathSelector, HtmlXPathSelector
 from scrapy.utils.spider import create_spider_for_request
 from scrapy.utils.misc import load_object
+from scrapy.utils.request import request_deferred
 from scrapy.utils.response import open_in_browser
-from scrapy.utils.url import any_to_uri
 from scrapy.utils.console import start_python_console
-from scrapy.conf import settings, Settings
-from scrapy.http import Request, Response, TextResponse
+from scrapy.settings import Settings
+from scrapy.http import Request, Response, HtmlResponse, XmlResponse
 
 class Shell(object):
 
     relevant_classes = (BaseSpider, Request, Response, BaseItem, \
         XPathSelector, Settings)
 
-    def __init__(self, crawler, update_vars=None, inthread=False):
+    def __init__(self, crawler, update_vars=None, code=None):
         self.crawler = crawler
-        self.vars = {}
         self.update_vars = update_vars or (lambda x: None)
-        self.item_class = load_object(settings['DEFAULT_ITEM_CLASS'])
-        self.inthread = inthread
+        self.item_class = load_object(crawler.settings['DEFAULT_ITEM_CLASS'])
+        self.spider = None
+        self.inthread = not threadable.isInIOThread()
+        self.code = code
+        self.vars = {}
 
-    def start(self, *a, **kw):
+    def start(self, url=None, request=None, response=None, spider=None):
         # disable accidental Ctrl-C key press from shutting down the engine
         signal.signal(signal.SIGINT, signal.SIG_IGN)
-        if self.inthread:
-            return threads.deferToThread(self._start, *a, **kw)
-        else:
-            self._start(*a, **kw)
-
-    def _start(self, url=None, request=None, response=None, spider=None):
         if url:
             self.fetch(url, spider)
         elif request:
             self.fetch(request, spider)
         elif response:
             request = response.request
-            self.populate_vars(request.url, response, request, spider)
-        start_python_console(self.vars)
+            self.populate_vars(response, request, spider)
+        else:
+            self.populate_vars()
+        if self.code:
+            print eval(self.code, globals(), self.vars)
+        else:
+            start_python_console(self.vars)
 
     def _schedule(self, request, spider):
+        spider = self._open_spider(request, spider)
+        d = request_deferred(request)
+        d.addCallback(lambda x: (x, spider))
+        self.crawler.engine.crawl(request, spider)
+        return d
+
+    def _open_spider(self, request, spider):
+        if self.spider:
+            return self.spider
         if spider is None:
             spider = create_spider_for_request(self.crawler.spiders, request, \
                 BaseSpider('default'), log_multiple=True)
-        self.crawler.engine.open_spider(spider)
-        return self.crawler.engine.schedule(request, spider)
+        spider.set_crawler(self.crawler)
+        self.crawler.engine.open_spider(spider, close_if_idle=False)
+        self.spider = spider
+        return spider
 
     def fetch(self, request_or_url, spider=None):
         if isinstance(request_or_url, Request):
@@ -65,31 +77,29 @@ class Shell(object):
         else:
             url = any_to_uri(request_or_url)
             request = Request(url, dont_filter=True)
+            request.meta['handle_httpstatus_all'] = True
         response = None
-        try:
-            response = threads.blockingCallFromThread(reactor, \
-                self._schedule, request, spider)
-        except:
-            log.err(Failure(), "Error fetching response", spider=spider)
-        self.populate_vars(url, response, request, spider)
+        response, spider = threads.blockingCallFromThread(reactor, \
+            self._schedule, request, spider)
+        self.populate_vars(response, request, spider)
 
-    def populate_vars(self, url=None, response=None, request=None, spider=None):
-        item = self.item_class()
-        self.vars['item'] = item
-        self.vars['settings'] = settings
-        if url:
-            if isinstance(response, TextResponse):
-                self.vars['xxs'] = XmlXPathSelector(response)
-                self.vars['hxs'] = HtmlXPathSelector(response)
-            self.vars['response'] = response
-            self.vars['request'] = request
-            self.vars['spider'] = spider
+    def populate_vars(self, response=None, request=None, spider=None):
+        self.vars['item'] = self.item_class()
+        self.vars['settings'] = self.crawler.settings
+        self.vars['spider'] = spider
+        self.vars['request'] = request
+        self.vars['response'] = response
+        self.vars['xxs'] = XmlXPathSelector(response) \
+            if isinstance(response, XmlResponse) else None
+        self.vars['hxs'] = HtmlXPathSelector(response) \
+            if isinstance(response, HtmlResponse) else None
         if self.inthread:
             self.vars['fetch'] = self.fetch
         self.vars['view'] = open_in_browser
         self.vars['shelp'] = self.print_help
         self.update_vars(self.vars)
-        self.print_help()
+        if not self.code:
+            self.print_help()
 
     def print_help(self):
         self.p("Available Scrapy objects:")
